# Toucan

A packages included Flask based framework to rapidly develop web applications 
and API endpoints. 

It comes with User Login section, Admin section to quickly get you going.

Also it includes a CMS admin, to quickly post blogs, create dynamic pages on the site.

Version: 0.0.*

## Install

    pip install toucan
    
## Create a new app

    cd your_dir 
    
    webcli create -a www
    
## Setup Project
    
    cd your_dir 
    
    python manage.py setup
    
### Start your server

    webcli local

Go to http://127.0.0.1:5000/

---

## Read The Docs

To dive into the documentation, Read the docs @ [http://mardix.github.io/Toucan/](http://mardix.github.io/Toucan/)

---

---
 


---


Core Modules:

    toucan.core
    
    toucan.decorators
    
    toucan.ext
    
    toucan.packages
    
--- 

## Read The Docs

Read the docs @ [http://mardix.github.io/Toucan/](http://mardix.github.io/Toucan/)

---


## Helping with Documentation

The documentation is written in Markdown and is located under `/docs` 
 
[MkDocs](http://www.mkdocs.org/) is used to create HTML from the `/docs` files. 

At the root of the directory, MkDocs uses the conf file `mkdocs.yml`. To add
 new menu, add it under `pages`

#### Edit Docs & make pull requests

Edit the files that needs updates or needs to be created under `/docs`. Files
are in Markdown format. 

If you are adding a new doc file, you may want to put it in `mkdocs.yml` under
`pages` so it can be shown in the menu.


Run this command to see the changes and look etc

    mkdocs serve
    

**Then commit and push your code in `master` to make a pull request.**

Do not COMMIT or PUSH the `/site` directory generated by MkDocs.
 
But if you wish to publish the doc site under your own github domain, 
run the command below:

    mkdocs gh-deploy --clean

But it's still best to make a pull request and share the docs.

That's it.

    
    